/**
 * Arrival section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoLookOut(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoArrivalChoice.LOOKOUT;
    var reqController = ctrl.arrival;
    var subController = ctrl.preBlackmail;
    var changeController = ctrl.preBlackmail;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.proposition;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = ``;
        var bindings = !global.kobold.history.shared.enslavement.nightOne.escapedBindings;

        if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
            toReturn += `[p]
                            ${bindings ? `You try to cover your eyes with your hands,
                            but find them still bound from the night before.
                            Instead, you roll over onto your side,
                            hiding your visage from the beaming sunlight,
                            letting it warm your back instead.` : `You cover your eyes with your hands,
                            protecting your delicate sight from the beaming sunlight.`}
                        [/p]
                        [p]
                            Despite having been out for what you can only presume be over half a day,
                            you still don't feel very refreshed.
                            In fact, you feel more drained than [i]before[/i] you passed out.
                            You could use a few extra hours of peace and quiet,
                            but since you're awake, you might as well start trying to figure out where you are,
                            and more importantly: how you're going to [b]escape[/b].
                        [/p]
                        [p]
                            Your heavy eyelids slowly open.
                            ${bindings ? `You wish you could wipe some of the crud from your eyes.` : `You wipe some of the crud from your eyes.`}
                            Your vision is blurry, but it rapidly sharpens.
                            Despite not feeling like you're ready to face the light,
                            you decide to give it a go anyway.
                        [/p]
                        [p]
                            ${bindings ? `Rolling onto your back once again` : `Removing your hands from your head`},
                            you accidentally stare directly into the sun,
                            scorching your retinas for a couple of milliseconds before you manage to avert your gaze.
                            Your eyes hurt.
                            Your headache flares up.
                            This was a mistake.
                        [/p]
                        [p]
                            Keeping your eyelids closed, you slowly scramble to your feet${bindings ? `, hindered, but not stopped by your bindings` : ``}.
                            After resting against the side of the cart for a moment, you slowly open your eyes once again.
                            Stepping on your tippy-toes, you peer through the iron bars lining the wooden walls.
                        [/p]
                        [p]
                            The brightly lit outside world is painful to look at, but not nearly as harmful as the sun itself.
                            You see a few shabby houses alongside a dirt road, followed by large stretches of farmland in their backyards.
                            You recognize this area.
                            You've been here before.
                            It's a place known simply as [i]the hamlet[/i],
                            a small village close to the human capital of Varanar.
                        [/p]
                        [p]
                            An old friend of yours lives here.
                            Seki, the alchemist-owl, who also happens to happily buy whatever stolen goods you bring him.
                            Besides being your [i]fence[/i], he's also the closest thing to a [i]father[/i] you've ever had.
                            Maybe [b]he[/b] can help you get out of this [b]mess[/b].
                        [/p]
                        [p]
                            A subtle [i]click[/i] resonates throughout your cell.
                            The door swings open widly, banging against the exterior wall,
                            the loud noise like a [b]dagger[/b] sinking into your skull, worsening your killer headache.
                            Turning to face the entryway, you witness Fenrir, the wolf that caught you the other day,
                            entering the jail-like carriage.
                            He is completely [b]naked[/b].
                        [/p]
                        [p]
                            "[color=gblue]Good morning, [b]lizard[/b]![/color]" the wolf booms,
                            his loud voice unknowingly [b]torturing[/b] your sleep-deprived brain.
                            You sigh internally.
                            You wish [b]all[/b] of yesterday had been part of your nightmare.
                            But alas, no such luck.
                        [/p]`;
        } else {
            toReturn += `[p]
                            You try to cover your eyes with your hands,
                            but find them still bound from the night before.
                            Instead, you roll over onto your side,
                            hiding your visage from the beaming sunlight,
                            letting it warm your back instead.
                        [/p]
                        [p]
                            Despite having slept for what you can only presume be over half a day,
                            you still don't feel very refreshed.
                            In fact, you feel more drained than [i]before[/i] your nap.
                            You could use a few extra hours of peace and quiet,
                            but since you're already awake, you might as well start trying to figure out where you are,
                            and more importantly: how you're going to [b]escape[/b].
                        [/p]
                        [p]
                            Your heavy eyelids slowly open.
                            You wish you could wipe some of the crud from your eyes.
                            Your vision is blurry, but it rapidly sharpens.
                            Despite not feeling like you're ready to face the light,
                            you decide to give it a go anyway.
                        [/p]
                        [p]
                            Rolling onto your back once again,
                            you accidentally stare directly into the sun,
                            scorching your retinas for a couple of milliseconds before you manage to avert your gaze,
                            hurting your eyes.
                            Your budding headache flares up.
                            This was a mistake.
                        [/p]
                        [p]
                            Keeping your eyelids closed, you slowly scramble to your feet, hindered, but not stopped by your bindings.
                            After resting against the side of the cart for a moment, you slowly open your eyes once again.
                            Stepping on your tippy-toes, you gaze through the iron bars lining the wooden walls.
                        [/p]
                        [p]
                            The brightly lit outside world is painful to look at, but not nearly as harmful as the sun itself.
                            You see a few shabby houses alongside a dirt road, followed by large stretches of farmland in their backyards.
                            You recognize this place.
                            You've been here before.
                            While asleep, you were taken to a place known simply as [i]the hamlet[/i],
                            a small village close to the human capital of Varanar.
                        [/p]
                        [p]
                            An old friend of yours lives here.
                            Seki, the alchemist-owl, who also happens to happily buy whatever stolen goods you bring him.
                            Besides being your [i]fence[/i], he's also the closest thing to a [i]father[/i] you've ever had.
                            Maybe [b]he[/b] can help you get out of this [b]mess[/b].
                        [/p]
                        [p]
                            A subtle [i]click[/i] resonates throughout your cell.
                            The door swings open widly, banging against the exterior wall,
                            the loud noise like a [b]dagger[/b] sinking into your skull, worsening your headache.
                            Turning to face the entryway, you witness Fenrir, the wolf that caught you the other day,
                            entering the jail-like carriage.
                            He is completely [b]naked[/b].
                        [/p]
                        [p]
                            "[color=gblue]Good morning, [b]lizard[/b]![/color]" the wolf booms,
                            his loud voice unknowingly [b]torturing[/b] your sleep-deprived brain.
                            You sigh internally.
                            You wish [b]all[/b] of yesterday had been part of your nightmare.
                            But alas, no such luck.
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
