/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellClimbUp(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellFallChoice.CLIMB;
    var reqController = ctrl.down;
    var subController = ctrl.climbUp;
    var changeController = ctrl.climbUp;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new HamletWellClimbRelent(ctrl);
    var secondNext = new HamletWellKeepClimbing(ctrl);

    var firstChoice = HamletWellClimbUpChoice.GIVE;
    var secondChoice = HamletWellClimbUpChoice.KEEP;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var rocky = global.kobold.history.shared.well.fell;
        var arrivalChoice = ctrl.arrival.get();
        var wanted = arrivalChoice === HamletWellArrivalChoice.CLIMB || arrivalChoice === HamletWellArrivalChoice.ROPE;
        var arrivalDescriptor = `You didn't want to be in here to begin with. Falling down was an accident, and nothing more. `;
        arrivalDescriptor += `If you wanted to explore these depths, you'd have climbed down here on your own accord.`;
        if (wanted) {
            arrivalDescriptor = `You wanted to explore this place, but after the tiring climb downwards, all you really want to do is leave. `;
            arrivalDescriptor += `You've already proven yourself. There's no point to sticking around.`;
            if (rocky) {
                arrivalDescriptor = `You wanted to explore this place, but after your harrowing [i]entrance[/i], all you really want to do is leave.`;
            }
        }
        var toReturn = `[p]
                            Time to get out of this damp hole.
                            ${arrivalDescriptor}
                            You reach up as high as you can, grabbing onto a rock protruding from the wall,
                            you find a similar stone to place a foot on, and so you begin to climb from the water, and hopefully out of the well.
                        [/p]
                        [p]
                            Your wall-scaling, while exhausting, goes without a hitch.
                            That is, until you reach the approximate halfway point.
                            You are getting tired, weary, perhaps even [i]too[/i] weary to get to the top.
                            You grab one of the cobblestone walls' rocks, as you've done a dozen times before.
                            Then, you try to lift yourself up to the next set of grip-points, only for the lime holding the stone in place to fail to support your weight.
                            You accidentally tear it straight from the wall, and in surprise, you let it slip from your grasp.
                            It drops down into the water below with a siumple, yet fright-inspiring [i]plop[/i].
                        [/p]
                        [p]
                            The sudden lack of grip throws you off balance, and almost sends you tumbling back down the well${rocky ? ` again` : ``}.
                            It is only through sheer luck and well-honed reflexes that you manage to quickly take hold of a different anchor point to maintain your position.
                            While you didn't fall, you are thoroughly shaken.
                            The moment the rock dislodged, your heart skipped a beat.
                            Doubt floods your brain.
                            Maybe this wasn't the best idea after all.
                            Maybe you should go back down and find another way to escape, before you hurt yourself.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Give up</button>`;

        var tooltip = global.parser.parse(`You'd rather not hurt yourself trying to get out.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 175px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Keep trying</button>`;

        var tooltip = global.parser.parse(`You're halfway there. Just a little bit more!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var HamletWellClimbUpChoice = {
    GIVE: 1,
    KEEP: 2
};
