/**
 * Doggo section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveFeed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.choices.doggo.FEED;
    var reqController = ctrl.doggo;
    var subController = ctrl.prePatch;
    var changeController = ctrl.feed;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new UndergroundCaveBasiPatch(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Still wary of the beast, you decide to try something.
                            You slowly reach for your ${global.kobold.inventory.createItemWithTooltip(new HeartyMeal())} while the basilisk circles around you.
                            As it reaches your front-end once more, you prudently set the basket down on the floor.
                            The creature seems captivated, its tongue rapidly flicking in and out of its mouth.
                            It turns its head towards the basket.
                            It can [b]smell[/b] the food.
                        [/p]
                        [p]
                            Having captured the crocodilian's attention, you open the lid of the wooden container.
                            The beast immediately [b]pounces[/b] on the basket, [b]ramming[/b] its head inside and [b]feasting[/b] on the soggy contents within,
                            like it's been starved for [b]weeks[/b].
                            Then again, maybe this is just how basilisks eat.
                            From what you can gather, they are [b]fierce[/b] creatures.
                            If it really was hungry, you have no doubt it would be eating [b]you[/b] right now.
                        [/p]
                        [p]
                            The contents of the ${global.kobold.inventory.createItemWithTooltip(new HeartyMeal())} are devoured wholly in less than a minute,
                            the monster [b]gorging[/b] and [b]feasting[/b] on them like there's no tomorrow.
                            At one point, you even fear it's going to eat the basket itself, the loud crunching of wood reverberating across the cavern.
                            Luckily, the beast seems smart enough to realize that's [b]not[/b] part of its meal.
                            It must have [i]accidentally[/i] chomped it a little.
                            Well, as long as it doesn't [i]accidentally[/i] chomp [b]you[/b], you're fine with that.
                        [/p]
                        [p]
                            Once finished with its meal, the basilisk retracts its face from the basket.
                            It looks up at you, as though begging for more, its forked tongue picking off some of the scraps clinging to the gaps in between his teeth.
                            Realizing you're out of food, it shoves the slightly damaged wooden basket to the side.
                            Taking the food container's place, the beast submissively lays itself down at your feet.
                        [/p]
                        [p]
                            [c]
                                [b]You have befriended the basilisk![/b]
                            [/c]
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
