/**
 * Doggo section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveFetch(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.choices.doggo.FETCH;
    var reqController = ctrl.doggo;
    var subController = ctrl.prePatch;
    var changeController = ctrl.fetch;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new UndergroundCaveBasiPatch(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var branch = ctrl.misc.weapon();
        var toReturn = `[p]
                            Still wary of the beast, you decide to try something.
                            You slowly reach for your ${global.kobold.inventory.createItemWithTooltip(branch)} while the basilisk circles around you.
                            As it reaches your front-end once more, you prudently wave the stick in front of its face.
                            The creature seems captivated, its eyes following the branch's every move.
                            Having captured its attention, you throw your ${global.kobold.inventory.createItemWithTooltip(branch)} as far as you can.
                        [/p]
                        [p]
                            The basilisk instantly gives chase, bursting out into a sprint,
                            moving far faster than you'd have imagined a beast of its [i]size[/i] to be capable of,
                            let alone one completely covered in weighty stone scales.
                            What an odd creature.
                            It [i]acts[/i] like a mixture between a dog and a cat,
                            but it [b]looks[/b] like an oversized alligator with a bunch of aesthetically-shaped stones attached to its back.
                        [/p]
                        [p]
                            Arriving at the stick, the massive lizard comes to a halt, its massive talons digging into the rock-like ground itself to slow it down.
                            Curious, you curl your toes in an attempt to mimic its motions,
                            yet your own claws can barely even [b]scratch[/b] the stone surface you're standing on.
                            It must be [b]really[/b] strong.
                            Or maybe it has razor-sharp talons.
                            Or both.
                        [/p]
                        [p]
                            The basilisk, having stopped directly in front of the branch you threw, is [i]staring[/i] at it.
                            At first, you wonder what the crocodilian is doing, but then you notice the stick slowly starting to change.
                            Its color changes from tree-brown to a deep grey, while simultaneously its texture visibly alters from vibrant wood to dull stone.
                            The creature is petrifying your weapon!
                        [/p]
                        [p]
                            The branch fully turned to stone, the lizard takes in its mouth, and happily carries it back over to you,
                            its tail wagging excitedly from side to side while dragging along the rock-floor.
                            You gingerly take your new, [i]enhanced[/i] club from the returning basilisk's mouth.
                            While a bit more [i]clumsy[/i] to wield,
                            you suppose the combined power of wood and stone make for a far more capable weapon than what you had before.
                            Once it realizes you don't intend on throwing the now-far-too-heavy stick a second time,
                            the basilisk submissively lies down at your feet.
                        [/p]
                        [p]
                            [c]
                                [b]You have befriended the basilisk![/b]
                            [/c]
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
