/**
 * Reflect section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveReflectionFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.stare;
    var changeController = ctrl.reflectFail;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new UndergroundCaveRelent(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.basiliskMet = true;
        global.kobold.history.shared.well.basiliskPetrified = true;
        var toReturn = `[p]
                            Your mind races, even as your body freezes.
                            How are you supposed to respond?!
                            You can't look away.
                            If it's a predator, it might take that as a sign of weakness.
                            Still, you're too [b]afraid[/b] to boldly stare back.
                            Those eyes are pretty scary.
                            You're left in an impasse, your frailty showing regardless of whether or not you look at the eyes.
                        [/p]
                        [p]
                            Then a thought flashes through your head.
                            An idea.
                            You bought something, something that can help!
                            Something that'll allow you to combine best of both worlds!
                            You're talking about the ${global.kobold.inventory.createItemWithTooltip(new SmallMirror())} in your backpack.
                            With it, you can give the monster something to stare at, without having to look at it yourself.
                            You're saved!
                        [/p]
                        [p]
                            A lot of animals get spooked by their own reflections.
                            Seki once told you that, anyway.
                            He mentioned [i]why[/i], but you can't really recall that part of his [i]lecture[/i].
                            Would the monster think you're its peer instead of prey, and thus leave you alone?
                            Or perhaps it'd find out that its got a real nasty look on its face.
                            Either way, the mirror your best bet.
                        [/p]
                        [p]
                            You keep your vision focused on the cavern wall, right next to the set of eyes staring at you,
                            trying to make it look like you [i]aren't[/i] afraid, without challenging the monster too much.
                            At the same time, you begin to look for the ${global.kobold.inventory.createItemWithTooltip(new SmallMirror())} on your person.
                        [/p]
                        [p]
                            Suddenly, your whole body jolts as something sharp pierces your fingertip!
                            A pained grunt escapes your muzzle.
                            Did you accidentally bump against an edgy stone?
                            No, it wasn't a rock.
                            Thanks to your haphazard adventure in the well,
                            your ${global.kobold.inventory.createItemWithTooltip(new SmallMirror())} seems to have broken into a million little pieces.
                            Must have gotten hit by some of the debris when the entire place came down ontop of your head.
                            Your heart sinks.
                            Terror settles in, your best plan shattered.
                        [/p]
                        [p]
                            The creature in the dark scuttles closer, redoubling its stare.
                            You can remotely make out the outline of something [b]big[/b] and [b]scaly[/b].
                            You can feel it growing [i]impatient[/i], like it's almost done [i]playing[/i] with you.
                            No, no, no!
                            You have no choice [b]but[/b] to gaze directly into its eyes, putting on your bravest face to hopefully keep the monster at bay.
                        [/p]
                        [p]
                            Fueled by desperation, you scoop the broken pieces to your front.
                            They loudly [b]scrape[/b] across the stone floor.
                            Once repositioned, your hands keep searching through the broken mirror's shards.
                            You get cut several times more, but you barely even notice, your mind completely [b]clogged[/b] with fright.
                            Your fingers clench around several fragments, trying, but failing to find one big enough to [i]wield[/i].
                            All the while, the creature's stare [b]burns[/b] itself into your mind.
                        [/p]
                        [p]
                            You stubbornly cling to your plan.
                            Both your hands continue to fumble about the shards.
                            If you can find a large enough mirror-piece, you'll be [b]saved[/b]!
                            But it's no use.
                            All of the fragments are far too tiny, completely useless.
                            You can feel your fingertips growing slightly more [i]stiff[/i] and [i]rigid[/i],
                            a fact you attribute to the multitude of small cuts you've sustained.
                            You doubt you could even properly [b]hold[/b] a shard a this point, even [i]if[/i] you managed to find one of sufficient size.
                        [/p]
                        [p]
                            Then you realize it's not [i]just[/i] your hands becoming numb.
                            [b]All[/b] of your extremities seem to be [i]unresponsive[/i].
                            As though half your body is [i]asleep[/i]!
                            Panic wells up inside you.
                            You try to rise to your feet, to flee as you should have done in the first place, but your legs refuse to function.
                            Your arms, too, appear to be frozen in place.
                        [/p]
                        [p]
                            You break eye contact with the monster.
                            You can't even turn your head away, your neck every bit as [i]stiff[/i] as your arms and legs.
                            Casting your gaze downwards, you notice your arms are [i]discolored[/i].
                            Your scales have become a dull grey instead of the usual green.
                        [/p]
                        [p]
                            Are you asleep?
                            Dreaming, perhaps?
                            Is this all a nightmare?
                            Did you never make it out of the well?
                            You try to open your mouth to scream, but even your muzzle isn't budging.
                            Staring at your own snout, you finally figure out what happened.
                            Your scales have turned to stone.
                            You've been petrified!
                        [/p]
                        [p]
                            You try every muscle in your body, to see which parts you can still move.
                            Your tongue is still in working order, although your mouth won't open.
                            Your eyes can dart around all they please, but your head itself is unmoving.
                            You retain [i]some[/i] form of control over your tail, the largest of your extremities still in some manner of working order.
                            Fingers are a no-go.
                            Entirely petrified.
                            Your toes, finally.
                            You can wriggle those around slightly, despite both your legs and your feet being locked in place.
                        [/p]
                        [p]
                            While most of your smaller organs and limbs are still fully functional,
                            your body as a whole is completely immobilized.
                            Shocked by this revelation, you barely even notice the creature you were so afraid of leaving its hole,
                            stepping out into the cave proper.
                            Your cross-eyed stare at your own muzzle slowly fading, you become aware of the large,
                            quadrupedal, rock-hided crocodillian standing right in front of you.
                            Your heart nearly skips a beat as you realize what you're dealing with here.
                            A [b]basilisk[/b]!
                        [/p]
                        [p]
                            Seki once told you stories about creatures that could petrify
                            anyone or anything unlucky enough to stare at them for prolonged periods of time,
                            but you thought he was just making things up!
                            You should have listened more carefully to the old bird!
                            On the bright side, while your fingers aren't fully petrified,
                            the small cuts you sustained while looking through the mirror shards have stopped bleeding,
                            probably sealed shut by your hardening scales.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(UndergroundCaveStareChoice.RELENT);
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.imageBackground.hide();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
