/**
 * Stare section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveStare(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = UndergroundCaveSurfaceChoice.STARE;
    var reqController = ctrl.surface;
    var subController = ctrl.stare;
    var changeController = ctrl.stare;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new UndergroundCaveResist(ctrl);
    var secondNext = new UndergroundCaveRelent(ctrl);

    var firstChoice = UndergroundCaveStareChoice.RESIST;
    var secondChoice = UndergroundCaveStareChoice.RELENT;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.basiliskMet = true;
        global.kobold.history.shared.well.basiliskPetrified = true;
        var toReturn = `[p]
                            You can't look away.
                            If this is some kind of predator, then you [b]need[/b] to keep staring at it.
                            Doing anything else'll be seen as a sign of weakness, which might trigger it to attack.
                            Besides, if you stop looking, you might not be able to react in time if it charges you or something.
                        [/p]
                        [p]
                            So you stare.
                            You stare deep into the pair of reptillian eyes, hoping whatever creature is watching you'll just [i]go away[/i].
                            While you may look like it, you are [b]not[/b] a quick bite or an easy prey.
                            You'll fight to your very last breath, in every way you can.
                            Even if that means you have to glare at it for an entire [b]hour[/b], you will not back down, and you will not relent.
                        [/p]
                        [p]
                            Neither the creature, nor you are willing to back down.
                            Minutes pass.
                            You haven't moved an inch.
                            The sight of the alluring, enchanting bright green eyes,
                            combined with the constant sound of dripping of water is sort of [i]hypnotizing[/i].
                            [i]Relaxing[/i], even.
                            If you weren't in the middle of an intense standoff with a lethal monster,
                            you could easily fall asleep to the sound of the splashing droplets.
                        [/p]
                        [p]
                            More time passes.
                            How much more?
                            You don't know.
                            You sort of [i]lost yourself[/i] in the creature's eyes for a while there.
                            Its cold stare is [b]captivating[/b].
                            [b]Enthralling[/b].
                            Maybe this wasn't such a good idea after all.
                            You should, at the very least, change your posture to be better prepared for an eventual [i]attack[/i].
                            You're still on your hands and knees, as you've been ever since you woke up after passing out.
                            Hardly the best stance for [i]combat[/i].
                        [/p]
                        [p]
                            You try to rise to your feet, but for some reason, you [i]can't[/i].
                            Neither your legs, nor your arms seem to be [i]moving[/i].
                            Are your limbs asleep from being on your hands and knees for so long or something?
                            You try to tilt your head downwards to get a better look at your forearms, but even your neck refuses service!
                            Panicking, you break eye contact with the monster.
                            At least your eyeballs can still move.
                        [/p]
                        [p]
                            Looking down, you notice your arms are [i]discolored[/i].
                            Your scales are [i]grey[/i] instead of the usual [b]green[/b].
                            Are you [i]asleep[/i]?
                            Dreaming, perhaps?
                            Is this all a nightmare?
                            You try to open your mouth to scream, but even your muzzle isn't budging.
                            Staring at your own snout, you finally figure out what happened.
                            Stone.
                            Your scales have turned to stone.
                            You've been petrified!
                        [/p]
                        [p]
                            You try every muscle in your body, to see which parts you can still move.
                            Your tongue is still in working order, although your mouth won't open.
                            Your eyes can dart around all they please, but your head itself is unmoving.
                            You retain [i]some[/i] form of control over your tail, the largest of your extremities still in some manner of working order.
                            Fingers are a no-go.
                            Entirely petrified.
                            Your toes, finally.
                            You can wriggle those around slightly, despite both your legs and your feet being locked in place.
                        [/p]
                        [p]
                            While most of your smaller organs and limbs are still fully functional,
                            your body as a whole is completely immobilized.
                            Shocked by this revelation, you barely even notice the creature you were so afraid of leaving its hole,
                            stepping out into the cave proper.
                            Your cross-eyed stare at your own muzzle slowly fading, you become aware of the large,
                            quadrupedal, rock-hided crocodillian standing right in front of you.
                            Your heart nearly skips a beat as you realize what you're dealing with here.
                            A [b]basilisk[/b]!
                        [/p]
                        [p]
                            Seki once told you stories about creatures that could petrify
                            anyone or anything unlucky enough to stare at them for prolonged periods of time,
                            but you thought he was just making things up!
                            You should have listened more carefully to the old bird!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Resist</button>`;

        var tooltip = global.parser.parse(`You need to break loose from the monster's enchantment!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Relent</button>`;

        var tooltip = global.parser.parse(`It's already too late. There's no point to struggling. Let it happen.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 220px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.imageBackground.hide();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var UndergroundCaveStareChoice = {
    RESIST: 1,
    RELENT: 2
};
