/**
 * Wake up section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeHideWakeUp(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You wake up many hours later, after a pained and troubled slumber,
                            drifting in and out of the realm of consciousness,
                            on the brink of being too awake to sleep and too asleep to think.
                        [/p]
                        [p]
                            At the cusp of dawn, you are roused from your restless drowse by a ray of blinding light shining in through a crack in the wooden wall of your shed.
                            You groaningly open your still slightly swollen eyelids.
                            Your entire body hurts, yet not nearly as much as it did yesterday.
                            While your face took most of the intense beating, it has seemingly gone [i]numb[/i],
                            the pain radiating from your visage dull and distant, intensifying only when you touch your wounded scales.
                        [/p]
                        [p]
                            Your mouth has stopped bleeding.
                            With your tongue, which is one of the few parts of your body that isn't aching, you feel around your gums.
                            One of your teeth outright [b]broke[/b], and fragments of it tore open the rest of your mouth, save for your tongue.
                            While you've managed to spit out most of the debris, the entirety of the inside of your mouth is lined with small cuts,
                            which you assume you'll be feeling for a long time still, despite them having stopped bleeding already.
                        [/p]
                        [p]
                            Your jaw, which you believed to be broken last night, seems to be in slightly better condition than you thought it was.
                            While it definitely hurts to open and close, it doesn't feel like anything is severely [b]fractured[/b] or [i]in the wrong place[/i].
                            Your snout, similarly, isn't in quite the poor shape you figured it was.
                            Your muzzle isn't deformed in any way, and apart from the tooth your lost, you don't think any [i]major[/i] damage was done.
                        [/p]
                        [p]
                            Maybe you were panicking just a little [i]too[/i] much yesterday.
                            While the kobold hybrid undeniably [i]fucked you up[/i], he was kind enough not to [b]permanently[/b] disfigure you.
                            He probably figured you'd be dead in a few days anyway.
                        [/p]
                        [p]
                            You shift to a seated position on your [i]bed[/i].
                            Your stomach still hurts quite a lot.
                            You hope you have no lasting [i]internal[/i] injuries, but you have no real way to check.
                            As you rise to your unsteady feet, a sudden wave of inexplicable euphoria washes over you.
                            As though your brain realizes [b]most[/b] of the pain is over, [b]for now[/b].
                        [/p]
                        [p]
                            Your thoughts wander towards the future.
                            While you may have kept your considerable [i]hoard[/i] of gold for now,
                            you doubt the Three-Tailed Rat will simply [b]stop[/b] coming after you when his extorter comes home empty-handed.
                            At best, you figure you'll be kidnapped, and get a chance to pay off your debts still.
                            At worst, you'll be poisoned, stabbed in the back or otherwise assassinated [b]before[/b] 
                            you can even explain that you actually [b]do[/b] have the rat's money.
                        [/p]
                        [p]
                            You wipe any lingering blood off of your still-sensitive face, before leaving the comfortable, familiar snugness of your small, wooden shack.
                            You take a deep breath of fresh morning air, or at least as deep as you can before your battered body begins to ache.
                        [/p]
                        [p]
                            The cool air clears your mind.
                            You take a moment to think, realizing that you've been surviving on [i]pure luck[/i] for a long time now.
                            You decide to seek a more assured fortune outside of the woods.
                            You can either go to Varanar directly, or you can first make a small stop at the rural hamlet just outside of town.
                            Whichever route you choose, you hope you'll end up better off than you are now.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }
    
    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeHideWakeUp";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.saved.hide.sleepContinued()) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.saved.hide.wakeChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the hamlet.</span>`;
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.saved.hide.sleepContinued()) {
            return;
        }
        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}
