/**
 * Fleeing section of Varanar, Night Two.
 * @param {NightTwoController} controller The Night Two controller.
 */
function NightTwoHide(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var stayHiddenId = arguments.callee.name + "ButtonOne";
    var attackId = arguments.callee.name + "ButtonTwo";

    var toStayHidden = new NightTwoHideStay(ctrl);
    var toAttack = new NightTwoHideAttack(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            It's too late to run, and you can't get over a wall that high.
                            The barrels.
                            Those are your best option.
                            Combined with the inherent darkness of the alleyway, the cover provided by them is sure to keep you hidden from a gang of drunkards.
                            At least you hope it will.
                        [/p]
                        [p]
                            You crouch down, crawling in between two of the barrels.
                            They [b]reek[/b] of refuse, probably containing something rotten, or maybe a family of rats made their home inside.
                            You have no choice [b]but[/b] to tolerate the stench, for now.
                            Concealed between a pair of barrels and a stone wall, you slowly turn around in your hiding spot,
                            facing the street-end to monitor for any new developments.
                        [/p]
                        [p]
                            A few members of the group pass by without even casting a glance down the alley in which you are hidden.
                            Your plan is working [b]perfectly[/b].
                            Heck, since they're not even looking this way, you didn't even need to bother with squeezing in between these smelly containers.
                            Taking your safety for granted, you let down your guard for a few seconds,
                            covering your snout to prevent the worst of the smell from reaching your nostrils.
                        [/p]
                        [p]
                            Your gaze returning to the entrance of the alley, a small, inadvertent gasp escapes your lips.
                            One of the men is drowsily standing at the far-end of the corridor, peering into it with half-attentive eyes.
                            You lower the hand covering your nose to your mouth, to muffle the quiet noise of your audible surprise.
                            Scared shitless, you reduce your posture as much as you can, curling up into a tiny little ball in hopes that he hasn't seen you [i]yet[/i].
                        [/p]
                        [p]
                            Luckily, humans are [b]not[/b] as skilled as kobolds are when it comes to seeing in the dark.
                            And even if they [b]were[/b], this one looks [b]so[/b] drunk he can barely stand on his own two feet,
                            let alone spot a tiny little lizard like yourself concealed behind a set of barrels in a pitch-black alley.
                            Still, despite not having seen you, the man casually saunters forwards, approaching your position with an unsteady gait.
                        [/p]
                        [p]
                            In spite of needing to brace himself against one of the walls to stay upright,
                            the human walks up to the very set of barrels you are hiding behind.
                            [b]Like he knows you're there.[/b]
                            Your heart races a million miles an hour.
                            You can [b]smell[/b] the stench of [b]booze[/b] lingering about him even through the odour of rot.
                            You let out a small whimper, almost betraying your location.
                            Luckily, he doesn't seem to notice.
                            You're still safe.
                            He [b]doesn't[/b] know.
                        [/p]
                        [p]
                            The man steadies himself against one of the barrels you're hiding behind, his boot-clad feet mere inches from your face.
                            He moves one of his hands to his groin, undoing the buttons of his linen pants.
                            Wait, what?
                            Reaching into his trousers, the man deftly lowers his underwear, exposing his [b]huge[/b], heavily oversized flaccid member,
                            an unwashed, manly fragrance mixing with the rest of the unpleasant scents.
                            Taking hold of his length, he points it downwards, not directly at you, but in your general vicinity.
                            [i]Oh no.[/i]
                        [/p]
                        [p]
                            Like the unsavory drunk that he is, the man releases his bladder,
                            a dark-yellow stream of pungent piss splattering against the wall besides you,
                            its hefty, acrid fragrance immediately [b]overpowering[/b] all of the other scents,
                            clogging your nose to the point of nearly making you [b]retch[/b].
                            That filthy human wasn't even looking for [b]you[/b], just for a place to take a leak!
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildStayHiddenChoice() {
        var disabled = ctrl.hide.has() ? "disabled" : "";
        var isSelected = ctrl.hide.get() === NightTwoHideChoice.STAY;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${stayHiddenId}" ${disabled}>Stay hidden</button>`;

        var tooltip = global.parser.parse(`Weather through the disgusting ordeal. He'll leave when he's done, right?`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildAttackChoice() {
        var disabled = ctrl.hide.has() ? "disabled" : "";
        var isSelected = ctrl.hide.get() === NightTwoHideChoice.ATTACK;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${attackId}" ${disabled} style="width: 160px;">Attack the man</button>`;

        var tooltip = global.parser.parse(`With his pants down, you have a clear shot at the human's most [i]delicate[/i] parts.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildStayHiddenChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildAttackChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + stayHiddenId), $("#" + attackId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerStayHiddenListener() {
        $("#" + stayHiddenId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.hide.set(NightTwoHideChoice.STAY);
            loadNextPart(toStayHidden);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerAttackListener() {
        $("#" + attackId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.hide.set(NightTwoHideChoice.ATTACK);
            loadNextPart(toAttack);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.alley.get() !== NightTwoAlleyChoice.HIDE) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += toStayHidden.build();
        part += toAttack.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.alley.get() !== NightTwoAlleyChoice.HIDE) {
            return;
        }

        toStayHidden.registerListeners();
        toAttack.registerListeners();

        if (ctrl.hide.has()) {
            return;
        }

        registerStayHiddenListener();
        registerAttackListener();
    };
}

var NightTwoHideChoice = {
    STAY: 1,
    ATTACK: 2
};

